LearningFunctions
=================

.. toctree::
   :maxdepth: 3

.. automodule:: psyneulink.core.components.functions.learningfunctions
   :members: LearningFunction, Kohonen, Hebbian, ContrastiveHebbian, Reinforcement, BayesGLM, BackPropagation, TDLearning
   :private-members:
   :exclude-members: Parameters



